<?php

	declare(strict_types=1);

	/**
	 * User: Daschmi (daschmi@daschmi.de)
	 * Date: 04.11.2021
	 * Time: 10:23
	 */
	
	define('WPSG_TBL_ORDERSTATES', wpsg_ShopController::getShop()->prefix.'wpsg_orderstates');
 
	class wpsg_mod_orderstates extends wpsg_mod_basic {
		
		var $id = 5600;		
		var $lizenz = 1;
		var $version = "4.4.9";
		var $hilfeURL = '';
		var $free = true;
		
		/**
		 * Erstellt ein neues Modul
		 */
		public function __construct() {
			
			$this->name = __('Bestellzustände', 'wpsg');
			$this->group = __('Bestellung', 'wpsg');
			$this->desc = __('Erlaubt das anlegen weiterer Bestellzustände.', 'wpsg');
			
			$this->shop = $GLOBALS['wpsg_sc'];
			$this->db = $GLOBALS['wpsg_db'];
			
		} 
		
		public function install() {
			
			require_once(WPSG_PATH_WP.'/wp-admin/includes/upgrade.php');
			
			$sql = "CREATE TABLE ".WPSG_TBL_ORDERSTATES." (
		   		id mediumint(9) NOT NULL AUTO_INCREMENT,
		   		name VARCHAR(255) NOT NULL,	
		   		deleted INT(1) NOT NULL, 		 
		   		PRIMARY KEY  (id),
		   		KEY deleted (deleted)
		   	) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;";
			
			dbDelta($sql);
			
		}

		public function settings_edit() {
			
			$this->shop->view['arStates'] = $this->getCustomStates(true);
			
			$this->shop->render(WPSG_PATH_VIEW.'/mods/mod_orderstates/settings_edit.phtml');			
			
		}
		
		public function settings_save() {
			
			if (isset($_REQUEST['wpsg_mod_orderstates']['states'])) {
				
				$arStates = json_decode($_REQUEST['wpsg_mod_orderstates']['states'], true);
				
				if (is_array($arStates)) {
				
					foreach ($arStates as $state_data) {
											
						$db_data = [
							'name' => wpsg_q(trim(\sanitize_text_field($state_data['name']))),
							'deleted' => wpsg_q((($state_data['deleted'] === '1')?'1':'0'))
						];
												
						if ($db_data['name'] === '') $db_data['name'] = wpsg_q(\sanitize_text_field(__('Unbenannt', 'wpsg')));
						
						if (intval($state_data['id']) > 0) {
							
							$this->db->UpdateQuery(WPSG_TBL_ORDERSTATES, $db_data, " `id` = '".intval($state_data['id'])."' ");
							
							$id = $state_data['id'];
							
						} else $id = $this->db->ImportQuery(WPSG_TBL_ORDERSTATES, $db_data);
						
						$this->shop->addTranslationString('wpsg_mod_orderstates_name_'.$id, $db_data['name']);
						
					}

				}
								
			}
			
		}
		
		public function init() {
			
			foreach ($this->getCustomStates() as $state) {
				
				$this->shop->arStatus[$this->id.'_'.$state['id']] = __($state['name'], 'wpsg');
				
			}
			
		}
		
		/* Modulfunktionen */
				
		public function getCustomStates(bool $bIncludeDeleted = false): array {
			
			$strQuery = "SELECT * FROM `".WPSG_TBL_ORDERSTATES."` WHERE 1 ";
			
			if (!$bIncludeDeleted) $strQuery .= " AND `deleted` != '1' ";
			
			$strQuery .= " ORDER BY `name` ASC ";
			 
			return $this->db->fetchAssoc($strQuery);
			
		}

	}
